#!/bin/bash -p

###
# Uninstallation script for VMware Fusion
# Copyright 2009 VMware, Inc.  All rights reserved.
###

export PATH=/bin:/sbin:/usr/bin:/usr/sbin

LIBDIR='/Library/Application Support/VMware Fusion'
APPDIR='/Applications/VMware Fusion.app'
QUICKLOOKDIR='/Library/QuickLook/VMware Fusion QuickLook.qlgenerator'
VMX="$LIBDIR"/vmware-vmx
UI='Contents/MacOS/vmware'
PACKAGE="VMware Fusion"
VERSION="2.0.2"
LAUNCHD_FILE='/Library/LaunchDaemons/com.vmware.launchd.vmware.plist'

# XXX These must be kept in sync with the return codes in uninstallFusion.m
VMX_NOT_QUIT_CODE=401
UI_NOT_QUIT_CODE=402
NOT_ADMIN_CODE=403
INSTALLER_NOT_QUIT_CODE=404
SUCCESS_CODE=200

if ps auxwww | grep "Installer.app" | grep -v 'grep' >/dev/null 2>&1; then
   echo "$INSTALLER_NOT_QUIT_CODE Please quit any open installers before running this program"
   exit 1
fi

if ps auxwww | grep "$VMX" | grep -v 'grep' >/dev/null 2>&1; then
   echo "$VMX_NOT_QUIT_CODE The VMX process is still running"
   exit 1
fi

if ps auxwww | grep "$UI" | grep -v 'grep' >/dev/null 2>&1; then
   echo "$UI_NOT_QUIT_CODE The UI process is still running"
   exit 1
fi

if [ $EUID -ne 0 ]; then
   # This should never happen when this shell script is invoked from the
   # graphical uninstaller wrapper.
   echo "$NOT_ADMIN_CODE The script is not running as root"
   exit 1
fi

test -x "$LIBDIR"/boot.sh && /bin/bash -p "$LIBDIR"/boot.sh --stop

# Uninstall ThinPrint files
if [ -x "$LIBDIR/thnuclnt/thnusetup.sh" ]; then
   /bin/bash -p "$LIBDIR/thnuclnt/thnusetup.sh" -u "$LIBDIR/thnuclnt" >> /dev/null 2>&1
fi

# TODO: We could use lsbom -p F $BOM_FILE to remove all files and
# directories here; it needs some pruning so we don't try to remove
# /Applications or /Library directories that happen to be empty.
rm -rf "$APPDIR"

# Uninstall QuickLook plugin
rm -rf "$QUICKLOOKDIR"

# Save the license file
if [ -e "$LIBDIR"/license.* ]; then
   tmpDir=`mktemp -d -t lic`
   cp "$LIBDIR"/license.* "$tmpDir"
   rm -rf "$LIBDIR"/*
   cp "$tmpDir"/* "$LIBDIR"
   rm -rf "$tmpDir"
else
   rm -rf "$LIBDIR"
fi

# Remove files generated at run time.
rm -rf /var/db/vmware
rm -rf /var/run/vmware

# Remove the package receipt
rm -rf "/Library/Receipts/Install VMware Fusion.pkg"

# Remove the helper VMs owned by the current user.
helperVmDir="$HOME/Library/Application Support/$PACKAGE/Virtual Machines/Helper"
if [ $UID -ne 0 ]; then
   # Script started with elevate privileges by non-root user using the uninstaller UI.
   # $HOME might be out of root's reach on a NIS server.
   sudo -u "$USER" rm -rf "$helperVmDir"
elif [ "$SUDO_USER" == '' ]; then
   # Script started by root.
   rm -rf "$helperVmDir"
else
   # Script started by sudo command. We are in a root account context.
   sudo -u "$SUDO_USER" rm -rf "$helperVmDir"
fi

# Remove the launchd file.
rm -f "$LAUNCHD_FILE"

echo "$SUCCESS_CODE Uninstallation was successful"
exit 0
